"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
let recognition;
let shouldBeRecognizing = false;
const CONTINUOUS_RECOGNITION = false;
const INTERIM_RESULTS = true;
const NOT_LISTENING_AFTER_COMMAND_TIME = 500;
function setup(recognitionOptions) {
    if (!('webkitSpeechRecognition' in window)) {
        throw new Error("Your browser doesn't support webkitSpeechRecognition API");
    }
    // @ts-ignore
    recognition = new webkitSpeechRecognition();
    recognition.continuous = CONTINUOUS_RECOGNITION;
    recognition.interimResults = INTERIM_RESULTS;
    recognition.lang = recognitionOptions.language;
    recognition.onend = onEndRecognitionCallback;
    recognition.onspeechstart = recognitionOptions.onSpeechStartCallback;
    recognition.onspeechend = recognitionOptions.onSpeechEndCallback;
    recognition.onresult = createResultCallback(recognitionOptions.resultCallback);
}
exports.setup = setup;
function startSpeechRecognition() {
    if (!recognition) {
        throw new Error('Recognition Engine was not setup');
    }
    shouldBeRecognizing = true;
    recognition.start();
}
exports.startSpeechRecognition = startSpeechRecognition;
function stopSpeechRecognition() {
    if (!recognition) {
        throw new Error('Recognition Engine was not setup');
    }
    shouldBeRecognizing = false;
    recognition.stop();
}
exports.stopSpeechRecognition = stopSpeechRecognition;
// Chromium tends to end recognition on its own
function onEndRecognitionCallback() {
    if (shouldBeRecognizing) {
        recognition.start();
    }
}
function createResultCallback(callback) {
    return (event) => {
        if (isSpeechOver(event.results)) {
            const lastSentence = getLastSentence(event.results);
            callback(lastSentence);
            setTimeout(() => startSpeechRecognition, NOT_LISTENING_AFTER_COMMAND_TIME);
        }
    };
}
function isSpeechOver(results) {
    return results[0].isFinal;
}
function getLastSentence(results) {
    const indexOfLastSentence = results.length - 1;
    const alternative = 0;
    return results[indexOfLastSentence][alternative].transcript;
}
//# sourceMappingURL=speechRecognitionEngine.js.map