"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const speechRecognitionEngine = require("./speechRecognitionEngine");
const recognitionRegistryService = require("./recognitionRegistryService");
let currentContext = 'DEFAULT';
function setup(recognitionServiceConfiguration) {
    const recognitionEngineConfiguration = Object.assign(Object.assign({}, recognitionServiceConfiguration), { resultCallback });
    speechRecognitionEngine.setup(recognitionEngineConfiguration);
}
exports.setup = setup;
function addGrammarListener(phrase, action, contextName = 'DEFAULT') {
    recognitionRegistryService.addEventToRegistry(phrase, action, contextName);
}
exports.addGrammarListener = addGrammarListener;
function changeContext(newContext) {
    currentContext = newContext;
}
exports.changeContext = changeContext;
function getCurrentContext() {
    return currentContext;
}
exports.getCurrentContext = getCurrentContext;
function resultCallback(recognisedPhrases) {
    const currentSentence = recognisedPhrases.trim().toLowerCase();
    const event = findGrammarMatchingSentence(currentSentence);
    if (event === undefined) {
        throw new Error('Grammar was not matched');
    }
    event.action();
}
function findGrammarMatchingSentence(sentenceToMatch) {
    return recognitionRegistryService
        .getRegistryOfContext(currentContext)
        .find(grammarEvent => isSentenceMatchingGrammar(sentenceToMatch, grammarEvent));
}
function isSentenceMatchingGrammar(sentence, grammarEvent) {
    return grammarEvent.grammar === sentence;
}
//# sourceMappingURL=speechRecognitionService.js.map